#ifndef UU_PARSE_H
#define UU_PARSE_H

#include "uulib/UUID.h"

IV uu_parse(pUCXT, const char *in, struct uu *out);

#endif
/* ex:set ts=2 sw=2 itab=spaces: */
